import datetime
import typing

import requests.types as rtypes
from requests import auth, cookies, exceptions, hooks, status_codes, structures, utils
from requests.packages.urllib3 import exceptions as urllib3_exceptions
from requests.packages.urllib3 import fields, filepost, util

default_hooks = hooks.default_hooks
CaseInsensitiveDict = structures.CaseInsensitiveDict
HTTPBasicAuth = auth.HTTPBasicAuth
cookiejar_from_dict = cookies.cookiejar_from_dict
get_cookie_header = cookies.get_cookie_header
RequestField = fields.RequestField
encode_multipart_formdata = filepost.encode_multipart_formdata
parse_url = util.parse_url
DecodeError = urllib3_exceptions.DecodeError
ReadTimeoutError = urllib3_exceptions.ReadTimeoutError
ProtocolError = urllib3_exceptions.ProtocolError
LocationParseError = urllib3_exceptions.LocationParseError
HTTPError = exceptions.HTTPError
MissingSchema = exceptions.MissingSchema
InvalidURL = exceptions.InvalidURL
ChunkedEncodingError = exceptions.ChunkedEncodingError
ContentDecodingError = exceptions.ContentDecodingError
ConnectionError = exceptions.ConnectionError
StreamConsumedError = exceptions.StreamConsumedError
guess_filename = utils.guess_filename
get_auth_from_url = utils.get_auth_from_url
requote_uri = utils.requote_uri
stream_decode_response_unicode = utils.stream_decode_response_unicode
to_key_val_list = utils.to_key_val_list
parse_header_links = utils.parse_header_links
iter_slices = utils.iter_slices
guess_json_utf = utils.guess_json_utf
super_len = utils.super_len
to_native_string = utils.to_native_string
codes = status_codes.codes

REDIRECT_STATI: typing.Tuple[int, ...]
DEFAULT_REDIRECT_LIMIT: int
CONTENT_CHUNK_SIZE: int
ITER_CHUNK_SIZE: int

class RequestEncodingMixin:
    @property
    def path_url(self) -> str: ...

class RequestHooksMixin:
    def register_hook(self, event: str, hook: rtypes.Hook) -> None: ...
    def deregister_hook(self, event: str, hook: rtypes.Hook) -> bool: ...

class Request(RequestHooksMixin):
    hooks: rtypes.Hooks
    method: str
    url: rtypes.URL
    headers: rtypes.Headers
    files: rtypes.Files
    data: rtypes.Data
    json: typing.Optional[rtypes.Json]
    params: rtypes.Params
    auth: rtypes.Auth
    cookies: rtypes.Cookies
    def __init__(
        self,
        method: str = ...,
        url: rtypes.URL = ...,
        *,
        headers: typing.Optional[rtypes.Headers] = ...,
        files: typing.Optional[rtypes.Files] = ...,
        data: typing.Optional[rtypes.Data] = ...,
        params: typing.Optional[rtypes.Params] = ...,
        auth: typing.Optional[rtypes.Auth] = ...,
        cookies: typing.Optional[rtypes.Cookies] = ...,
        hooks: typing.Optional[rtypes.Hooks] = ...,
        json: typing.Optional[rtypes.Json] = ...,
    ) -> None: ...
    def prepare(self) -> PreparedRequest: ...

class PreparedRequest(RequestEncodingMixin, RequestHooksMixin):
    method: str
    url: str
    headers: rtypes.Headers
    body: rtypes.Body
    hooks: rtypes.Hooks
    def __init__(self) -> None: ...
    def prepare(
        self,
        method: str = ...,
        url: rtypes.URL = ...,
        *,
        headers: typing.Optional[rtypes.Headers] = ...,
        files: typing.Optional[rtypes.Files] = ...,
        data: typing.Optional[rtypes.Data] = ...,
        params: typing.Optional[rtypes.Params] = ...,
        auth: typing.Optional[rtypes.Auth] = ...,
        cookies: typing.Optional[rtypes.Cookies] = ...,
        hooks: typing.Optional[rtypes.Hooks] = ...,
        json: typing.Optional[rtypes.Json] = ...,
    ) -> None: ...
    def copy(self) -> PreparedRequest: ...
    def prepare_method(self, method: str) -> None: ...
    def prepare_url(self, url: str, params: typing.Optional[rtypes.Params]) -> None: ...
    def prepare_headers(self, headers: typing.Optional[rtypes.Headers]) -> None: ...
    def prepare_body(
        self, data: typing.Optional[rtypes.Data], files: typing.Optional[rtypes.Files], json: typing.Optional[rtypes.Json] = ...,
    ) -> None: ...
    def prepare_content_length(self, body: typing.Optional[rtypes.Body]) -> None: ...
    def prepare_auth(self, auth: typing.Optional[rtypes.Auth], url: rtypes.URL = ...) -> None: ...
    def prepare_cookies(self, cookies: typing.Optional[rtypes.Cookies]) -> None: ...
    def prepare_hooks(self, hooks: typing.Optional[rtypes.Hooks]) -> None: ...

class Response:
    __attrs__: typing.Any
    _content: typing.Optional[bytes]  # undocumented
    status_code: int
    headers: rtypes.Headers
    raw: object
    url: str
    encoding: str
    history: typing.List[Response]
    reason: str
    cookies: rtypes.Cookies
    elapsed: datetime.timedelta
    request: PreparedRequest
    def __init__(self) -> None: ...
    def __bool__(self) -> bool: ...
    def __nonzero__(self) -> bool: ...
    def __iter__(self) -> typing.Iterator[bytes]: ...
    def __enter__(self) -> Response: ...
    def __exit__(self, *args: object) -> None: ...
    @property
    def next(self) -> typing.Optional[PreparedRequest]: ...
    @property
    def ok(self) -> bool: ...
    @property
    def is_redirect(self) -> bool: ...
    @property
    def is_permanent_redirect(self) -> bool: ...
    @property
    def apparent_encoding(self) -> str: ...
    def iter_content(self, chunk_size: typing.Optional[int] = ..., decode_unicode: bool = ...) -> typing.Iterator[object]: ...
    def iter_lines(
        self,
        chunk_size: typing.Optional[int] = ...,
        decode_unicode: bool = ...,
        delimiter: typing.Optional[typing.Union[typing.Text, bytes]] = ...,
    ) -> typing.Iterator[object]: ...
    @property
    def content(self) -> bytes: ...
    @property
    def text(self) -> str: ...
    def json(self, **kwargs: object) -> object: ...
    @property
    def links(self) -> typing.Dict[typing.Any, typing.Any]: ...
    def raise_for_status(self) -> None: ...
    def close(self) -> None: ...



"""
This type stub file was generated by pyright.
"""
from typing import Dict

from pactman.mock.pact import Interaction, Pact
from urllib3.response import HTTPResponse

from ..verifier.result import Result

class Request:
    def __init__(self, method: str, path: str, query: str, headers: Dict[str, str], body: Dict[str, object]) -> None: ...

class RecordResult(Result):
    reason: str
    def start(self, interaction: Interaction) -> None: ...
    def fail(self, message: str, path: str = ...) -> bool: ...

class PactRequestHandler:
    def __init__(self, pact: Pact) -> None: ...
    def validate_request(self, method: str) -> HTTPResponse: ...
    def get_body(self) -> Dict[str, object]: ...
    def respond_for_interaction(self, reason: str) -> HTTPResponse: ...
    def handle_response_encoding(self, response: Dict[str, object], headers: Dict[str, str]) -> bytes: ...
    def write_pact(self, interaction: Interaction) -> None: ...



"""
This type stub file was generated by pyright.
"""
import os
from types import TracebackType
from typing import Any, Callable, Dict, List, Optional, Protocol, Type, TypedDict, TypeVar, Union, overload

from pactman.mock.consumer import Consumer
from pactman.mock.matchers import Matcher
from pactman.mock.provider import Provider

"""API for creating a contract and configuring the mock service."""
USE_MOCKING_SERVER = os.environ.get("PACT_USE_MOCKING_SERVER", "no") == "yes"

class VersionInfoLike(Protocol):
    """This is a minimal type stub for semver.Version."""

    major: int
    minor: int
    patch: int
    prerelease: Optional[Union[str, int]]
    build: Optional[Union[str, int]]

def ensure_pact_dir(pact_dir: str) -> None: ...

class ProviderState(TypedDict):
    name: str
    params: Dict[str, str]

class Request(TypedDict):
    method: str
    path: str

class V2Interaction(TypedDict):
    providerState: str
    request: Request

class V3Interaction(TypedDict):
    providerStates: List[ProviderState]
    request: Request

Interaction = Union[V2Interaction, V3Interaction]

class Pacticipant(TypedDict):
    name: str

class PactStructMetaSpecification(TypedDict):
    version: str

class PactStructMeta(TypedDict):
    pactSpecification: PactStructMetaSpecification

class PactStruct(TypedDict):
    consumer: Pacticipant
    provider: Pacticipant
    interactions: List[Interaction]
    metadata: PactStructMeta

P = TypeVar('P', bound=Pact)

class Pact(object):
    """
    Represents a contract between a consumer and provider.

    Provides Python context handlers to configure the Pact mock service to
    perform tests on a Python consumer. For example:

    >>> from pactman import Consumer, Provider
    >>> pact = Consumer('consumer').has_pact_with(Provider('provider'))
    >>> (pact.given('the echo service is available')
    ...  .upon_receiving('a request is made to the echo service')
    ...  .with_request('get', '/echo', query={'text': 'Hello!'})
    ...  .will_respond_with(200, body='Hello!'))
    >>> with pact:
    ...   requests.get(pact.uri + '/echo?text=Hello!')

    The GET request is made to the mock service, which will verify that it
    was a GET to /echo with a query string with a key named `text` and its
    value is `Hello!`. If the request does not match an error is raised, if it
    does match the defined interaction, it will respond with the text `Hello!`.
    """

    HEADERS: Dict[str, str] = ...

    scheme: str
    file_write_mode: str
    host_name: str
    log_dir: str
    pact_dir: str
    port: int
    provider: Provider
    ssl: bool
    sslcert: str
    sslkey: str
    version: str
    semver: VersionInfoLike
    use_mocking_server: bool
    _interactions: List[Interaction]

    _pact_dir_checked: bool
    _enter_count: int

    # it's not actually a property, but it's the only way
    # to parameterize the generic with the type of P
    @property
    def consumer(self: P) -> Consumer[P]: ...
    def __init__(
        self: P,
        consumer: Consumer[P],
        provider: Provider,
        host_name: str = ...,
        port: int = ...,
        log_dir: str = ...,
        ssl: bool = ...,
        sslcert: Optional[str] = ...,
        sslkey: Optional[str] = ...,
        pact_dir: str = ...,
        version: str = ...,
        file_write_mode: str = ...,
        use_mocking_server: bool = ...,
    ) -> None:
        """
        Constructor for Pact.

        :param consumer: The consumer for this contract.
        :type consumer: pact.Consumer
        :param provider: The provider for this contract.
        :type provider: pact.Provider
        :param host_name: The host name where the mock service is running.
        :type host_name: str
        :param port: The port number where the mock service is running. Defaults
            to a port >= 8050.
        :type port: int
        :param log_dir: The directory where logs should be written. Defaults to
            the current directory.
        :type log_dir: str
        :param ssl: Flag to control the use of a self-signed SSL cert to run
            the server over HTTPS , defaults to False.
        :type ssl: bool
        :param sslcert: Path to a custom self-signed SSL cert file, 'ssl'
            option must be set to True to use this option. Defaults to None.
        :type sslcert: str
        :param sslkey: Path to a custom key and self-signed SSL cert key file,
            'ssl' option must be set to True to use this option.
            Defaults to None.
        :type sslkey: str
        :param pact_dir: Directory where the resulting pact files will be
            written. Defaults to the current directory.
        :type pact_dir: str
        :param version: The Pact Specification version to use, defaults to
            '2.0.0'.
        :type version: str
        :param file_write_mode: `overwrite` or `merge`. Use `merge` when
            running multiple mock service instances in parallel for the same
            consumer/provider pair. Ensure the pact file is deleted before
            running tests when using this option so that interactions deleted
            from the code are not maintained in the file. Defaults to
            `overwrite`.
        :type file_write_mode: str
        :param use_mocking_server: If True the mocking will be done using a
            HTTP server rather than patching urllib3 connections.
        :type use_mocking_server: bool
        """
        ...
    @property
    def uri(self) -> str: ...
    BASE_PORT_NUMBER: int = ...
    @classmethod
    def allocate_port(cls) -> int: ...
    def check_existing_file(self) -> None: ...
    @property
    def pact_json_filename(self) -> str: ...
    @overload
    def given(self: P, provider_state: None) -> P: ...
    @overload
    def given(self: P, provider_state: str, **params: str) -> P: ...
    @overload
    def given(self: P, provider_state: List[ProviderState]) -> P:
        """
        Define the provider state for this pact.

        When the provider verifies this contract, they will use this field to
        setup pre-defined data that will satisfy the response expectations.

        In pact v2 the provider state is a short sentence that is unique to describe
        the provider state for this contract. For example:

            "an alligator with the given name Mary exists and the spam nozzle is operating"

        In pact v3 the provider state is a list of state specifications with a name and
        associated params to define specific values for the state. This may be provided
        in two ways. Either call with a single list, for example:

            [
                {
                    "name": "an alligator with the given name exists",
                    "params": {"name" : "Mary"}
                }, {
                    "name": "the spam nozzle is operating",
                    "params" : {}
                }
            ]

        or for convenience call `.given()` with a string as in v2, which implies a single
        provider state, with params taken from keyword arguments like so:

            .given("an alligator with the given name exists", name="Mary")

        If additional provider states are required for a v3 pact you may either use the list
        form above, or make an additional call to `.and_given()`.

        If you don't have control over the provider, and they cannot implement a provider
        state, you may use an explicit `None` for the provider state value. This is
        discouraged as it introduces fragile external dependencies in your tests.

        :param provider_state: The state as described above.
        :type provider_state: string or list as above
        :rtype: Pact
        """
        ...
    def and_given(self: P, provider_state: str, **params: str) -> P:
        """
        Define an additional provider state for this pact.

        Supply the provider state name and any params taken in keyword arguments like so:

            .given("an alligator with the given name exists", name="Mary")

        :param provider_state: The state as described above.
        :type provider_state: string or list as above
        :rtype: Pact
        """
        ...
    def setup(self) -> None: ...
    def start_mocking(self) -> None: ...
    def stop_mocking(self) -> None: ...
    start_service: Callable[[Pact], None] = ...
    stop_service: Callable[[Pact], None] = ...
    def upon_receiving(self: P, scenario: str) -> P:
        """
        Define the name of this contract.

        :param scenario: A unique name for this contract.
        :type scenario: basestring
        :rtype: Pact
        """
        ...
    def verify(self) -> None:
        """
        Have the mock service verify all interactions occurred.

        Calls the mock service to verify that all interactions occurred as
        expected, and has it write out the contracts to disk.

        :raises AssertionError: When not all interactions are found.
        """
        ...
    def with_request(
        self: P,
        method: str,
        path: Union[str, Matcher],
        body: Optional[Union[List[Any], Dict[str, Any]]] = ...,
        headers: Optional[Dict[str, str]] = ...,
        query: Optional[Union[str, Dict[str, str]]] = ...,
    ) -> P:
        """
        Define the request the request that the client is expected to perform.

        :param method: The HTTP method.
        :type method: str
        :param path: The path portion of the URI the client will access.
        :type path: str, Matcher
        :param body: The request body, can be a string or an object that will
            serialize to JSON, like list or dict, defaults to None.
        :type body: list, dict or None
        :param headers: The headers the client is expected to include on with
            this request. Defaults to None.
        :type headers: dict or None
        :param query: The query options the client is expected to send. Can be
            a dict of keys and values, or a URL encoded string.
            Defaults to None.
        :type query: dict, str, or None
        :rtype: Pact
        """
        ...
    def will_respond_with(
        self: P,
        status: int,
        headers: Optional[Dict[str, str]] = ...,
        body: Optional[Union[Matcher, str, Dict[str, Any], List[Any]]] = ...,
    ) -> P:
        """
        Define the response the server is expected to create.

        :param status: The HTTP status code.
        :type status: int
        :param headers: All required headers. Defaults to None.
        :type headers: dict or None
        :param body: The response body, or a collection of Matcher objects to
            allow for pattern matching. Defaults to None.
        :type body: Matcher, dict, list, basestring, or None
        :rtype: Pact
        """
        ...
    _auto_mocked: bool = ...
    def __enter__(self) -> None:
        """
        Handler for entering a Python context.

        Sets up the mock service to expect the client requests.
        """
        ...
    def __exit__(self, exc_type: Type[Exception], exc_val: Exception, exc_tb: TracebackType) -> None:
        """
        Handler for exiting a Python context.

        Calls the mock service to verify that all interactions occurred as
        expected, and has it write out the contracts to disk.
        """
        ...
    def construct_pact(self, interaction: Interaction) -> PactStruct:
        """Construct a pact JSON data structure for the interaction.
        """
        ...



"""
This type stub file was generated by pyright.
"""

from pactman.mock.pact import Pact, Request
from pactman.mock.pact_request_handler import RecordResult, Request

class RequestVerifier:
    interaction_name: str = ...
    def __init__(self, pact: Pact, interaction: Request, result: RecordResult) -> None: ...
    def log_context(self) -> None: ...
    def verify(self, request: Request) -> bool: ...
    def verify_query(self, spec_query: str, request: Request) -> bool: ...
    def compare_dict(self, data: object, spec: object, path: str) -> bool: ...



from typing import IO, Any, Callable, Iterable, List, Mapping, MutableMapping, Optional, Text, Tuple, Union

from requests import auth, cookies, models

RequestsCookieJar = cookies.RequestsCookieJar
Request = models.Request
Response = models.Response
PreparedRequest = models.PreparedRequest

Hook = Callable[[Response], Any]
_Hooks = MutableMapping[Text, List[Hook]]
_HooksInput = MutableMapping[Text, Union[Iterable[Hook], Hook]]

Body = Union[bytes, Text]

URL = Union[str, bytes, Text]
Params = Union[bytes, MutableMapping[Text, Text]]
Data = Union[Text, bytes, Mapping[str, Any], Mapping[Text, Any], Iterable[Tuple[Text, Optional[Text]]], IO]
Headers = MutableMapping[Text, Text]
Cookies = Union[RequestsCookieJar, MutableMapping[Text, Text]]
Files = MutableMapping[Text, IO[Any]]
Auth = Union[Tuple[Text, Text], auth.AuthBase, Callable[[PreparedRequest], PreparedRequest]]
Timeout = Union[float, Tuple[float, float], Tuple[float, None]]
AllowRedirects = bool
Proxies = MutableMapping[Text, Text]
Hooks = _HooksInput
Stream = bool
Verify = Union[bool, Text]
Cert = Union[Text, Tuple[Text, Text]]
Json = Any



"""
This type stub file was generated by pyright.
"""

from pactman.mock.matchers import EachLike, Equals, Includes, Like, SomethingLike, Term
from pactman.mock.provider import Provider

from .mock.consumer import Consumer
from .mock.pact import Pact

__all__ = ['Consumer', 'Pact', 'Provider', 'EachLike', 'Equals', 'Includes', 'Like', 'SomethingLike', 'Term']
"""Python methods for interactive with a Pact Mock Service."""



from typing import TYPE_CHECKING, Any, Awaitable, Callable, Optional, Sequence, Union

import requests
import requests.auth
import requests.cookies
from starlette.types import Receive, Scope, Send

ASGIInstance = Callable[[Receive, Send], Awaitable[None]]
ASGI2App = Callable[[Scope], ASGIInstance]
ASGI3App = Callable[[Scope, Receive, Send], Awaitable[None]]

if TYPE_CHECKING:
    import requests.types as rtypes

class TestClient(requests.Session):
    def __init__(
        self, app: Union[ASGI2App, ASGI3App], base_url: str = ..., raise_server_exceptions: bool = ..., root_path: str = ...,
    ) -> None: ...
    def request(
        self,
        method: str = ...,
        url: rtypes.URL = ...,
        *,
        headers: Optional[rtypes.Headers] = ...,
        files: Optional[rtypes.Files] = ...,
        data: Optional[rtypes.Data] = ...,
        params: Optional[rtypes.Params] = ...,
        auth: Optional[rtypes.Auth] = ...,
        cookies: Optional[rtypes.Cookies] = ...,
        hooks: Optional[rtypes.Hooks] = ...,
        json: Optional[rtypes.Json] = ...,
        timeout: Optional[rtypes.Timeout] = ...,
        allow_redirects: Optional[rtypes.AllowRedirects] = ...,
        proxies: Optional[rtypes.Proxies] = ...,
        stream: Optional[rtypes.Stream] = ...,
        verify: Optional[rtypes.Verify] = ...,
        cert: Optional[rtypes.Cert] = ...,
    ) -> requests.Response: ...
    def get(
        self,
        url: rtypes.URL = ...,
        *,
        headers: Optional[rtypes.Headers] = ...,
        params: Optional[rtypes.Params] = ...,
        auth: Optional[rtypes.Auth] = ...,
        cookies: Optional[rtypes.Cookies] = ...,
        hooks: Optional[rtypes.Hooks] = ...,
        timeout: Optional[rtypes.Timeout] = ...,
        allow_redirects: Optional[rtypes.AllowRedirects] = ...,
        proxies: Optional[rtypes.Proxies] = ...,
        stream: Optional[rtypes.Stream] = ...,
        verify: Optional[rtypes.Verify] = ...,
        cert: Optional[rtypes.Cert] = ...,
    ) -> requests.Response: ...
    def options(
        self,
        url: rtypes.URL = ...,
        *,
        headers: Optional[rtypes.Headers] = ...,
        params: Optional[rtypes.Params] = ...,
        auth: Optional[rtypes.Auth] = ...,
        cookies: Optional[rtypes.Cookies] = ...,
        hooks: Optional[rtypes.Hooks] = ...,
        timeout: Optional[rtypes.Timeout] = ...,
        allow_redirects: Optional[rtypes.AllowRedirects] = ...,
        proxies: Optional[rtypes.Proxies] = ...,
        stream: Optional[rtypes.Stream] = ...,
        verify: Optional[rtypes.Verify] = ...,
        cert: Optional[rtypes.Cert] = ...,
    ) -> requests.Response: ...
    def head(
        self,
        url: rtypes.URL = ...,
        *,
        headers: Optional[rtypes.Headers] = ...,
        params: Optional[rtypes.Params] = ...,
        auth: Optional[rtypes.Auth] = ...,
        cookies: Optional[rtypes.Cookies] = ...,
        hooks: Optional[rtypes.Hooks] = ...,
        timeout: Optional[rtypes.Timeout] = ...,
        allow_redirects: Optional[rtypes.AllowRedirects] = ...,
        proxies: Optional[rtypes.Proxies] = ...,
        stream: Optional[rtypes.Stream] = ...,
        verify: Optional[rtypes.Verify] = ...,
        cert: Optional[rtypes.Cert] = ...,
    ) -> requests.Response: ...
    def delete(
        self,
        url: rtypes.URL = ...,
        *,
        headers: Optional[rtypes.Headers] = ...,
        params: Optional[rtypes.Params] = ...,
        auth: Optional[rtypes.Auth] = ...,
        cookies: Optional[rtypes.Cookies] = ...,
        hooks: Optional[rtypes.Hooks] = ...,
        timeout: Optional[rtypes.Timeout] = ...,
        allow_redirects: Optional[rtypes.AllowRedirects] = ...,
        proxies: Optional[rtypes.Proxies] = ...,
        stream: Optional[rtypes.Stream] = ...,
        verify: Optional[rtypes.Verify] = ...,
        cert: Optional[rtypes.Cert] = ...,
    ) -> requests.Response: ...
    def post(
        self,
        url: rtypes.URL = ...,
        *,
        headers: Optional[rtypes.Headers] = ...,
        files: Optional[rtypes.Files] = ...,
        data: Optional[rtypes.Data] = ...,
        params: Optional[rtypes.Params] = ...,
        auth: Optional[rtypes.Auth] = ...,
        cookies: Optional[rtypes.Cookies] = ...,
        hooks: Optional[rtypes.Hooks] = ...,
        json: Optional[rtypes.Json] = ...,
        timeout: Optional[rtypes.Timeout] = ...,
        allow_redirects: Optional[rtypes.AllowRedirects] = ...,
        proxies: Optional[rtypes.Proxies] = ...,
        stream: Optional[rtypes.Stream] = ...,
        verify: Optional[rtypes.Verify] = ...,
        cert: Optional[rtypes.Cert] = ...,
    ) -> requests.Response: ...
    def put(
        self,
        url: rtypes.URL = ...,
        *,
        headers: Optional[rtypes.Headers] = ...,
        files: Optional[rtypes.Files] = ...,
        data: Optional[rtypes.Data] = ...,
        params: Optional[rtypes.Params] = ...,
        auth: Optional[rtypes.Auth] = ...,
        cookies: Optional[rtypes.Cookies] = ...,
        hooks: Optional[rtypes.Hooks] = ...,
        json: Optional[rtypes.Json] = ...,
        timeout: Optional[rtypes.Timeout] = ...,
        allow_redirects: Optional[rtypes.AllowRedirects] = ...,
        proxies: Optional[rtypes.Proxies] = ...,
        stream: Optional[rtypes.Stream] = ...,
        verify: Optional[rtypes.Verify] = ...,
        cert: Optional[rtypes.Cert] = ...,
    ) -> requests.Response: ...
    def patch(
        self,
        url: rtypes.URL = ...,
        *,
        headers: Optional[rtypes.Headers] = ...,
        files: Optional[rtypes.Files] = ...,
        data: Optional[rtypes.Data] = ...,
        params: Optional[rtypes.Params] = ...,
        auth: Optional[rtypes.Auth] = ...,
        cookies: Optional[rtypes.Cookies] = ...,
        hooks: Optional[rtypes.Hooks] = ...,
        json: Optional[rtypes.Json] = ...,
        timeout: Optional[rtypes.Timeout] = ...,
        allow_redirects: Optional[rtypes.AllowRedirects] = ...,
        proxies: Optional[rtypes.Proxies] = ...,
        stream: Optional[rtypes.Stream] = ...,
        verify: Optional[rtypes.Verify] = ...,
        cert: Optional[rtypes.Cert] = ...,
    ) -> requests.Response: ...
    def websocket_connect(self, url: str, subprotocols: Optional[Sequence[str]] = ..., **kwargs: object) -> Any: ...
    def __enter__(self) -> "TestClient": ...
    def __exit__(self, *args: object) -> None: ...
    async def lifespan(self) -> None: ...
    async def wait_startup(self) -> None: ...
    async def wait_shutdown(self) -> None: ...



"""
This type stub file was generated by pyright.
"""

import logging
from typing import NoReturn

log = logging.getLogger(__name__)

class Result:
    PASS: bool = ...
    FAIL: bool = ...
    success: bool = ...
    def start(self, message: str) -> None: ...
    def end(self) -> None: ...
    def warn(self, message: str) -> NoReturn: ...
    def fail(self, message: str, path: str = ...) -> NoReturn: ...



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['pactman-stubs', 'requests-stubs', 'starlette-stubs']

package_data = \
{'': ['*'], 'pactman-stubs': ['mock/*', 'verifier/*']}

install_requires = \
['fastapi>=0.63.0,<0.64.0', 'pactman>=2.28.0,<3.0.0', 'requests>=2.25.1,<3.0.0']

setup_kwargs = {
    'name': 'outcome-stubs',
    'version': '0.5.3',
    'description': 'Stub files for various python packages.',
    'long_description': '# stubs-py\n![Continuous Integration](https://github.com/outcome-co/stubs-py/workflows/Continuous%20Integration/badge.svg) ![version-badge](https://img.shields.io/badge/version-0.5.3-brightgreen)\n\nStubs for various python packages.\n\nThey are often partial, sometimes incomplete.\n\n## Usage\n\n```sh\npoetry add outcome-stubs\n```\n\n## Development\n\nRemember to run `./bootstrap.sh` when you clone the repository.\n',
    'author': 'Outcome Engineering',
    'author_email': 'engineering@outcome.co',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/outcome-co/stubs-py',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8.6,<4.0.0',
}


setup(**setup_kwargs)



"""
This type stub file was generated by pyright.
"""
from typing import Dict, List, NoReturn

from pactman import Pact
from pactman.mock.pact import Interaction
from urllib3.response import HTTPResponse

from .pact_request_handler import PactRequestHandler

class MockURLOpenHandler(PactRequestHandler):
    path: str
    pact: Pact
    headers: Dict[str, str]
    interactions: List[Interaction]
    def __init__(self, config: Pact) -> None: ...
    def terminate(self) -> None: ...
    def setup(self, interactions: List[Interaction]) -> None: ...
    def verify(self) -> None: ...
    def __call__(
        self, method: str, url: str, redirect: bool = ..., headers: Dict[str, str] = ..., body: bytes = ..., **kw: object
    ) -> HTTPResponse: ...
    def get_interaction(self, path: str) -> Interaction: ...
    def handle_failure(self, reason: str) -> NoReturn: ...
    def handle_success(self, interaction: Interaction) -> None: ...
    def respond_for_interaction(self, interaction: Interaction) -> HTTPResponse: ...
